from __future__ import unicode_literals

from django.conf.urls import include, url
from django.core import urlresolvers
from wagtail.wagtailadmin.menu import MenuItem
from wagtail.wagtailcore import hooks

from . import urls


@hooks.register('register_admin_urls')
def register_admin_urls():
    return [
        url(r'^metadata/', include(urls)),
    ]


@hooks.register('register_settings_menu_item')
def register_menu_settings():
    return MenuItem(
        'Metadata',
        urlresolvers.reverse('wagtailmetadata'),
        classnames='icon icon-pick',
        order=300
    )



import warnings

from django.conf import settings
from django.template.loader import render_to_string
from wagtail.wagtailcore.models import Site
from wagtailmetadata.models import SiteMetadataPreferences


def meta_tags(request, page):
    site = Site.find_for_request(request)
    try:
        global_settings = SiteMetadataPreferences.objects.get(site=site)
    except SiteMetadataPreferences.DoesNotExist:
        warnings.warn('Your global metadata settings are not defined for {0}'.format(site))
        return ''

    page.meta_image = page.search_image or global_settings.site_image
    page.meta_description = page.search_description or global_settings.site_description

    if page.meta_image:
        page.meta_image = page.meta_image.get_rendition(filter='original')
        page.meta_image.full_url = request.build_absolute_uri(page.meta_image.url)

    page.absolute_url = request.build_absolute_uri(page.url)
    return render_to_string('wagtailmetadata/parts/tags.html', {
        'page': page,
        'site_name': settings.WAGTAIL_SITE_NAME,
        'global_settings': global_settings,
    })



from django import template
from wagtailmetadata import tags

register = template.Library()


@register.simple_tag(takes_context=True)
def meta_tags(context):
    request = context['request']
    page = context['self']

    return tags.meta_tags(request, page)



from django.db import models
from django.utils.translation import ugettext_lazy
from wagtail.wagtailadmin.edit_handlers import FieldPanel, MultiFieldPanel
from wagtail.wagtailcore.models import Page, Site
from wagtail.wagtailimages.edit_handlers import ImageChooserPanel

TWITTER_CARD_TYPES = [
    ('summary', 'Summary card'),
    ('summary_large_image', 'Summary card with large image'),
]


class SiteMetadataPreferences(models.Model):
    site = models.OneToOneField(Site, unique=True, db_index=True, editable=False)
    site_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        related_name='+',
        on_delete=models.SET_NULL,
        help_text="""
        This is the default image that will be shown when your page is
         shared on social media or is found on search engines """)
    site_description = models.TextField(help_text="""
    This is the default description displayed when your page is shared on
     social media or is found on search engines""")

    # Twitter settings
    card_type = models.CharField(max_length=128, choices=TWITTER_CARD_TYPES)

    general_panels = [
        MultiFieldPanel([
            ImageChooserPanel('site_image'),
            FieldPanel('site_description')
        ], heading='General')
    ]

    twitter_panels = [
        MultiFieldPanel([
            FieldPanel('card_type')
        ], heading='Twitter')
    ]


class MetadataPageMixin(models.Model):
    search_image = models.ForeignKey(
        'wagtailimages.Image',
        null=True,
        blank=True,
        related_name='+',
        on_delete=models.SET_NULL
    )

    promote_panels = [
        MultiFieldPanel([
            FieldPanel('slug'),
            FieldPanel('seo_title'),
            FieldPanel('show_in_menus'),
            FieldPanel('search_description'),
            ImageChooserPanel('search_image'),
        ], ugettext_lazy('Common page configuration')),
    ]

    class Meta:
        abstract = True



#!/usr/bin/env python
"""
Install wagtail-metadata using setuptools
"""

with open('README.rst', 'r') as f:
    readme = f.read()

from setuptools import find_packages, setup

setup(
    name='wagtail-metadata',
    version='0.1.4',
    description="A tool to assist with metadata for social media.",
    long_description=readme,
    author='Liam Brenner',
    author_email='liam@takeflight.com.au',
    url='https://github.com/takeflight/wagtail-metadata',

    install_requires=[
        'wagtail>=1.0',
    ],
    zip_safe=False,
    license='BSD License',

    packages=find_packages(),

    include_package_data=True,
    package_data={},

    classifiers=[
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
        'License :: OSI Approved :: BSD License',
    ],
)



import jinja2
from jinja2.ext import Extension
from wagtailmetadata import tags


@jinja2.contextfunction
def meta_tags(context):
    request = context['request']
    page = context['page']

    return jinja2.Markup(tags.meta_tags(request, page))


class WagtailMetadataExtension(Extension):
    def __init__(self, environment):
        super().__init__(environment)

        self.environment.globals.update({
            'meta_tags': meta_tags,
        })



# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-09 00:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('wagtailmetadata', '0002_auto_20160607_2150'),
    ]

    operations = [
        migrations.AlterField(
            model_name='sitemetadatapreferences',
            name='site_image',
            field=models.ForeignKey(blank=True, help_text='\n        This is the default image that will be shown when your page is\n         shared on social media or is found on search engines ', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='wagtailimages.Image'),
        ),
    ]
